@@ -1,24 +1,7 @@
-# The MIT License (MIT)
+# SPDX-FileCopyrightText: 2017 Tony DiCola for Adafruit Industries
 #
-# Copyright (c) 2017 Tony DiCola for Adafruit Industries
-#
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in
-# all copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
-# THE SOFTWARE.
+# SPDX-License-Identifier: MIT
+
 """
 `adafruit_lsm9ds1`
 ====================================================
@@ -61,7 +44,6 @@ import adafruit_bus_device.spi_device as spi_device
 from micropython import const
 
 # Internal constants and register values:
-# pylint: disable=bad-whitespace
 _LSM9DS1_ADDRESS_ACCELGYRO = const(0x6B)
 _LSM9DS1_ADDRESS_MAG = const(0x1E)
 _LSM9DS1_XG_ID = const(0b01101000)
@@ -122,6 +104,7 @@ _LSM9DS1_REGISTER_INT_SRC_M = const(0x31)
 _MAGTYPE = True
 _XGTYPE = False
 _SENSORS_GRAVITY_STANDARD = 9.80665
+_SPI_AUTO_INCR = 0x40
 
 # User facing constants/module globals.
 ACCELRANGE_2G = 0b00 << 3
@@ -135,7 +118,6 @@ MAGGAIN_16GAUSS = 0b11 << 5  # +/- 16 gauss
 GYROSCALE_245DPS = 0b00 << 3  # +/- 245 degrees/s rotation
 GYROSCALE_500DPS = 0b01 << 3  # +/- 500 degrees/s rotation
 GYROSCALE_2000DPS = 0b11 << 3  # +/- 2000 degrees/s rotation
-# pylint: enable=bad-whitespace
 
 
 def _twos_comp(val, bits):
@@ -184,10 +166,10 @@ class LSM9DS1:
     @property
     def accel_range(self):
         """The accelerometer range.  Must be a value of:
-          - ACCELRANGE_2G
-          - ACCELRANGE_4G
-          - ACCELRANGE_8G
-          - ACCELRANGE_16G
+        - ACCELRANGE_2G
+        - ACCELRANGE_4G
+        - ACCELRANGE_8G
+        - ACCELRANGE_16G
         """
         reg = self._read_u8(_XGTYPE, _LSM9DS1_REGISTER_CTRL_REG6_XL)
         return (reg & 0b00011000) & 0xFF
@@ -211,10 +193,10 @@ class LSM9DS1:
     @property
     def mag_gain(self):
         """The magnetometer gain.  Must be a value of:
-          - MAGGAIN_4GAUSS
-          - MAGGAIN_8GAUSS
-          - MAGGAIN_12GAUSS
-          - MAGGAIN_16GAUSS
+        - MAGGAIN_4GAUSS
+        - MAGGAIN_8GAUSS
+        - MAGGAIN_12GAUSS
+        - MAGGAIN_16GAUSS
         """
         reg = self._read_u8(_MAGTYPE, _LSM9DS1_REGISTER_CTRL_REG2_M)
         return (reg & 0b01100000) & 0xFF
@@ -238,9 +220,9 @@ class LSM9DS1:
     @property
     def gyro_scale(self):
         """The gyroscope scale.  Must be a value of:
-          - GYROSCALE_245DPS
-          - GYROSCALE_500DPS
-          - GYROSCALE_2000DPS
+        - GYROSCALE_245DPS
+        - GYROSCALE_500DPS
+        - GYROSCALE_2000DPS
         """
         reg = self._read_u8(_XGTYPE, _LSM9DS1_REGISTER_CTRL_REG1_G)
         return (reg & 0b00011000) & 0xFF
@@ -467,6 +449,7 @@ class LSM9DS1_SPI(LSM9DS1):
     def _read_bytes(self, sensor_type, address, count, buf):
         if sensor_type == _MAGTYPE:
             device = self._mag_device
+            address |= _SPI_AUTO_INCR
         else:
             device = self._xg_device
         with device as spi:
